@@ -166,6 +166,7 @@ public:
 		rateUnknown,
 		rate6khz = 6000,
 		rate8khz = 8000,
+		rate16khz = 16000,
 		rate44khz = 44100
 	};
 
@@ -225,7 +226,11 @@ public:
 		pcm16Stereo,
 		pcm16Mono,
 		pcm32Stereo,
-		pcm32Mono
+		pcm32Mono,
+
+		// speex codecs
+		speexVoice,	// narrow band
+		speexAudio
 	};
 	typedef enum Encoding Encoding;
 
