@@ -171,7 +171,7 @@ void AudioFile::create(const char *name, Info *myinfo, bool exclusive, timeout_t
 	int pcm = 0;
 	unsigned char aufile[24];
 	unsigned char riffhdr[40];
-	char *ext = strrchr(name, '/');
+	const char *ext = strrchr(name, '/');
 
 	if(!ext)
 		ext = strrchr(name, '\\');
