@@ -171,6 +171,9 @@ const char *Audio::getExtension(Encoding encoding)
 		return ".mp3";
 	case voxADPCM:
 		return ".vox";
+	case speexVoice:
+	case speexAudio:
+		return ".spx";
 	case sx73Voice:
 	case sx96Voice:
 		return ".sx";
@@ -252,6 +255,8 @@ Audio::Encoding Audio::getEncoding(const char *name)
 		return sx73Voice;
 	else if(!stricmp(name, "sx96"))
 		return sx96Voice;
+	else if(!stricmp(name, "spx") || !stricmp(name, "speex"))
+		return speexVoice;
 	else if(!stricmp(name, "g723_16") || !stricmp(name, "g.723_16"))
 		return g723_2bit;
 	else if(!stricmp(name, "g723_24") || !stricmp(name, "g.723_24"))
@@ -287,8 +292,11 @@ const char *Audio::getMIME(Info &info)
 
 	if(info.format == snd)
 	{
-		if(info.encoding == g721ADPCM)
+		switch(info.encoding)
+		{
+		case g721ADPCM:
 			return "audio/x-adpcm";
+		}
 		return "audio/basic";
 	}
 
@@ -297,6 +305,9 @@ const char *Audio::getMIME(Info &info)
 
 	switch(info.encoding)
 	{
+	case speexVoice:
+	case speexAudio:
+		return "application/x-spx";
 	case mp1Audio:
 	case mp2Audio:
 	case mp3Audio:
@@ -356,6 +367,9 @@ const char *Audio::getName(Encoding encoding)
 		return "sx73";
 	case sx96Voice:
 		return "sx96";
+	case speexVoice:
+	case speexAudio:
+		return "speex";
 	}
 	return "unknown";
 }
@@ -831,6 +845,8 @@ Audio::timeout_t Audio::getFraming(Encoding encoding, timeout_t timeout)
 		fa = 40;
 		break;
 	case gsmVoice:
+	case speexVoice:
+	case speexAudio:
 		fa = 20;
 		break;
 	case sx96Voice:
@@ -864,6 +880,10 @@ int Audio::getCount(Encoding encoding)
 	case sx73Voice:
 	case sx96Voice:
 		return 120;
+	case speexVoice:
+		return 160;
+	case speexAudio:
+		return 320;
 	case unknownEncoding:
 		return 0;
 	case g723_2bit:
@@ -894,6 +914,12 @@ int Audio::getFrame(Encoding encoding, int samples)
 	case msgsmVoice:
 		framing = 65;
 		break;
+	case speexVoice:
+		framing = 20;
+		break;
+	case speexAudio:
+		framing = 40;
+		break;
 	case gsmVoice:
 		framing = 33;
 		break;
@@ -973,6 +999,8 @@ Audio::Rate Audio::getRate(Encoding encoding)
 	case cdaStereo:
 	case cdaMono:
 		return rate44khz;
+	case speexAudio:
+		return rate16khz;
 	default:
 		return rate8khz;
 	}
