@@ -52,6 +52,22 @@ ssize_t AudioDevice::getBuffer(Encoded data, size_t count)
 	return 0;
 }
 
+unsigned AudioDevice::putNativeSamples(Linear samples, unsigned count)
+{
+	swapEndian(info, samples, count);
+	return putSamples(samples, count);
+}
+
+unsigned AudioDevice::getNativeSamples(Linear samples, unsigned count)
+{
+	unsigned result = getSamples(samples, count);
+	if(!result)
+		return 0;
+
+	swapEndian(info, samples, result);
+	return result;
+}
+
 unsigned AudioDevice::bufMono(Linear samples, unsigned count)
 {
 	unsigned fill, index;
