@@ -18,7 +18,7 @@
 
 static const char *fname(const char *cp)
 {
-	char *fn = strrchr(cp, '/');
+	const char *fn = strrchr(cp, '/');
 	if(!fn)
 		fn = strrchr(cp, '\\');
 	if(fn)
