@@ -92,7 +92,7 @@ int main(int argc, char **argv)
 
 static const char *fname(const char *cp)
 { 
-        char *fn = strrchr(cp, '/');
+        const char *fn = strrchr(cp, '/');
         if(!fn)
                 fn = strrchr(cp, '\\');
         if(fn)
